Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(701)

Unified Diff: media/gpu/ipc/service/gpu_video_decode_accelerator.h

Issue 2881553002: Add |texture_target_| and |pixel_format_| to media::PictureBuffer (Closed)
Patch Set: removed IPC changes Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/gpu/ipc/service/gpu_video_decode_accelerator.h
diff --git a/media/gpu/ipc/service/gpu_video_decode_accelerator.h b/media/gpu/ipc/service/gpu_video_decode_accelerator.h
index 6f38d421fa03a42984880c1ec1ddffc9d56c9d58..db2c79dd2ce50b51bf44c38ae28060a1c7634581 100644
--- a/media/gpu/ipc/service/gpu_video_decode_accelerator.h
+++ b/media/gpu/ipc/service/gpu_video_decode_accelerator.h
@@ -138,8 +138,11 @@ class GpuVideoDecodeAccelerator
// The texture target as requested by ProvidePictureBuffers().
uint32_t texture_target_;
- // The number of textures per picture buffer as requests by
- // ProvidePictureBuffers()
+ // The format of the picture buffers requested by ProvidePictureBuffers().
+ VideoPixelFormat pixel_format_;
+
+ // The number of textures per picture buffer as requested by
+ // ProvidePictureBuffers().
uint32_t textures_per_buffer_;
// The message filter to run VDA::Decode on IO thread if VDA supports it.
« no previous file with comments | « media/gpu/ipc/client/gpu_video_decode_accelerator_host.cc ('k') | media/gpu/ipc/service/gpu_video_decode_accelerator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698